{% load i18n %}

<div class="feedback_likert_rating">
  <label title="{{scale_text}}" class="feedback_likert_label">
    <input data-id="radio_{{idx}}" name="feedback_scale" class="feedback_radio" type="radio" {{active}}/>
    <span class="feedback_icon feedback_icon_inactive">
      <img src="{{ina_icon}}" alt="{{unicode_icon}}"/>
    </span>
    <span class="feedback_icon feedback_icon_active">
      <img src="{{act_icon}}" alt="{{unicode_icon}}"/>
    </span>
    <br/>
    <span>{% trans scale_text %}</span>
  </label>
</div>
