$(function () {

    const cssUrl = "https://cdn.jsdelivr.net/npm/@edx/paragon@20.45.5/dist/paragon.min.css";

    $('<link>').attr({
        href: cssUrl,
        rel: "stylesheet"
    }).appendTo('head');

});
