"""
An edX XBlock designed to allow people to provide feedback on our
course resources, and to think and synthesize about their experience
in the course.
"""
import os
from pathlib import Path

ROOT_DIRECTORY = Path(os.path.dirname(os.path.abspath(__file__)))
